@@ -100,12 +100,16 @@ pub const RESULTS_CANCEL: gtk::ResponseType = gtk::ResponseType::Cancel;
 
 // Window Styles
 #[cfg(windows)]
+/// Standard window
 pub const WINDOWSTYLE_NORMAL: windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_STYLE = windows_sys::Win32::UI::WindowsAndMessaging::WS_OVERLAPPEDWINDOW;
 #[cfg(windows)]
+/// A window with only a close button
 pub const WINDOWSTYLE_ONLYEXIT: windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_STYLE = windows_sys::Win32::UI::WindowsAndMessaging::WS_SYSMENU;
 #[cfg(windows)]
-pub const WINDOWSTYLE_CAPTION: windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_STYLE = windows_sys::Win32::UI::WindowsAndMessaging::WS_CAPTION;
+/// Window with no caption
+pub const WINDOWSTYLE_NOCAPTION: windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_STYLE = windows_sys::Win32::UI::WindowsAndMessaging::WS_CAPTION;
 
 
 #[cfg(unix)]
+/// Standard window
 pub const WINDOWSTYLE_NORMAL: gtk::WindowType = gtk::WindowType::Toplevel;
