@@ -1,13 +1,17 @@
+use crate::io::get_app_dirs;
+use crate::io::storage::Storage;
 use crate::window::{Application, Frame};
 
 #[cfg(windows)]
+/// Run nxui::window::Application
 pub fn run_app(application: Box<dyn Application>) {
     // Get window title
-    let title = application.title();
+    let app_name = application.app_name();
     // Get attributes
     let attributes = application.attributes();
+    let storage = Storage::new(get_app_dirs(app_name));
     // startup process
-    application.startup();
+    application.startup(storage);
 
     // Create a window
     use windows_sys::{Win32::Foundation::*, Win32::Graphics::Gdi::ValidateRect, Win32::System::LibraryLoader::GetModuleHandleA, Win32::UI::WindowsAndMessaging::*};
@@ -49,7 +53,7 @@ pub fn run_app(application: Box<dyn Application>) {
         let atom = RegisterClassA(&wc);
         debug_assert!(atom != 0);
 
-        let win = CreateWindowExA(0, "window".as_ptr(), title.as_ptr(), attributes.style, attributes.x, attributes.y, attributes.width, attributes.height, 0, 0, instance, std::ptr::null_mut());
+        let win = CreateWindowExA(0, "window".as_ptr(), attributes.title.as_ptr(), attributes.style, attributes.x, attributes.y, attributes.width, attributes.height, 0, 0, instance, std::ptr::null_mut());
         let frame = Frame::new(win);
         application.ui(frame);
         let mut message = std::mem::zeroed();
@@ -64,13 +68,15 @@ pub fn run_app(application: Box<dyn Application>) {
 }
 
 #[cfg(unix)]
+/// Run nxui::window::Application
 pub fn run_app(application: Box<dyn Application>) {
     // Get window title
-    let title = application.title();
+    let app_name = application.app_name();
     // Get attributes
     let attributes = application.attributes();
+    let storage = Storage::new(get_app_dirs(app_name));
     // startup process
-    application.startup();
+    application.startup(storage);
 
     // Create a window
     use gtk::prelude::*;
@@ -78,7 +84,9 @@ pub fn run_app(application: Box<dyn Application>) {
 
     let window = gtk::Window::new(gtk::WindowType::Toplevel);
 
-    window.set_title(title.as_str());
+    window.set_title(attributes.title.as_str());
+    window.set_default_size(attributes.width,attributes.height);
+    window.set_window_position(gtk::WindowPosition::Center);
 
     window.connect_delete_event(|_, _| {
         gtk::main_quit();
