@@ -21,7 +21,7 @@ impl Application for DemoWindow {
     }
 
     fn attributes(&self) -> WindowAttributes {
-        WindowAttributes::new(WINDOWSTYLE_NORMAL, "NXUI Window".to_string(),1280, 750, 500, 500)
+        WindowAttributes::new(WINDOWSTYLE_NORMAL, "NXUI Window".to_string(),1280, 750, 100, 100)
     }
 
     fn startup(&self,storage: Storage) {
@@ -31,7 +31,7 @@ impl Application for DemoWindow {
 
     fn ui(&self,frame: Frame) {
         frame.show();
-        match MessageBox::new("Do you want to maximize the window?".to_string(), "Do you want to maximize the window?".to_string(), DIALOGSTYLE_QUESTION, BUTTONSTYLE_YESNO).show() {
+        match MessageBox::new("Do you want to maximize the window?".to_string(), "Do you want to maximize the window?".to_string(), DIALOGSTYLE_QUESTION, BUTTONSTYLE_YESNO).show(frame.clone()) {
             RESULTS_YES => {
                 frame.show_maximized();
                 frame.set_title("The window has been maximized.".to_string());
