@@ -5,6 +5,7 @@ use crate::io::storage::Storage;
 pub mod demowindow;
 
 #[cfg(windows)]
+#[derive(Debug,Copy,Clone)]
 pub struct Frame {
     /// Window body
     handle: windows_sys::Win32::Foundation::HWND
@@ -47,6 +48,11 @@ impl Frame {
         unsafe { ShowWindow(self.handle,SW_HIDE); }
     }
 
+    /// Returns the window handle.
+    pub fn get_window(&self) -> windows_sys::Win32::Foundation::HWND {
+        self.handle
+    }
+
     /// Set window title
     pub fn set_title(&self,title: String) {
         use windows_sys::Win32::UI::WindowsAndMessaging::SetWindowTextA;
@@ -64,6 +70,15 @@ impl Frame {
     }
 }
 
+#[cfg(windows)]
+impl Default for Frame {
+    fn default() -> Self {
+        Self {
+            handle: 0
+        }
+    }
+}
+
 #[cfg(windows)]
 pub struct WindowAttributes {
     pub style: windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_STYLE,
@@ -108,6 +123,7 @@ pub trait Application {
 
 
 #[cfg(unix)]
+#[derive(Debug,Copy,Clone)]
 pub struct Frame {
     /// Window body
     handle: gtk::Window
@@ -152,6 +168,11 @@ impl Frame {
         self.handle.set_title(title.as_str());
     }
 
+    /// Returns the window handle.
+    pub fn get_window(&self) -> gtk::Window {
+        self.handle
+    }
+
     /// Set window position
     pub fn set_position(&self,x: i32,y: i32) {
         use gtk::prelude::*;
@@ -159,6 +180,15 @@ impl Frame {
     }
 }
 
+#[cfg(unix)]
+impl Default for Frame {
+    fn default() -> Self {
+        Self {
+            handle: gtk::Window::default()
+        }
+    }
+}
+
 #[cfg(unix)]
 pub struct WindowAttributes {
     pub style: gtk::WindowType,
